aboutsummaryrefslogtreecommitdiffstats
path: root/codecs/ilbc/iLBC_encode.h
diff options
context:
space:
mode:
authormarkster <markster@f38db490-d61c-443f-a65b-d21fe96a405b>2004-10-14 05:15:48 +0000
committermarkster <markster@f38db490-d61c-443f-a65b-d21fe96a405b>2004-10-14 05:15:48 +0000
commit92a945abe63a2579c66257696ddda848ab5a3ea0 (patch)
tree0deebbd8647eb5799eef8ddc6f084ec945574299 /codecs/ilbc/iLBC_encode.h
parent850b151d70bb9a1dc28edd3c0d737b57b1ab43cc (diff)
Update to new iLBC codec
git-svn-id: http://svn.digium.com/svn/asterisk/trunk@3997 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'codecs/ilbc/iLBC_encode.h')
-rwxr-xr-xcodecs/ilbc/iLBC_encode.h69
1 files changed, 37 insertions, 32 deletions
diff --git a/codecs/ilbc/iLBC_encode.h b/codecs/ilbc/iLBC_encode.h
index 5e4de46c5..3628e7545 100755
--- a/codecs/ilbc/iLBC_encode.h
+++ b/codecs/ilbc/iLBC_encode.h
@@ -1,32 +1,37 @@
-
-/******************************************************************
-
- iLBC Speech Coder ANSI-C Source Code
-
- iLBC_encode.h
-
- Copyright (c) 2001,
- Global IP Sound AB.
- All rights reserved.
-
-******************************************************************/
-
-#ifndef __iLBC_ILBCENCODE_H
-#define __iLBC_ILBCENCODE_H
-
-#include "iLBC_define.h"
-
-short initEncode( /* (o) Number of bytes encoded */
- iLBC_Enc_Inst_t *iLBCenc_inst /* (i/o) Encoder instance */
-);
-
-void iLBC_encode(
- unsigned char *bytes, /* (o) encoded data bits iLBC */
- float *block, /* (o) speech vector to encode */
- iLBC_Enc_Inst_t *iLBCenc_inst /* (i/o) the general encoder
- state */
-);
-
-#endif
-
-
+
+/******************************************************************
+
+ iLBC Speech Coder ANSI-C Source Code
+
+ iLBC_encode.h
+
+ Copyright (C) The Internet Society (2004).
+ All Rights Reserved.
+
+******************************************************************/
+
+#ifndef __iLBC_ILBCENCODE_H
+#define __iLBC_ILBCENCODE_H
+
+#include "iLBC_define.h"
+
+short initEncode( /* (o) Number of bytes
+ encoded */
+ iLBC_Enc_Inst_t *iLBCenc_inst, /* (i/o) Encoder instance */
+ int mode /* (i) frame size mode */
+);
+
+void iLBC_encode(
+
+
+ unsigned char *bytes, /* (o) encoded data bits iLBC */
+ float *block, /* (o) speech vector to
+ encode */
+ iLBC_Enc_Inst_t *iLBCenc_inst /* (i/o) the general encoder
+ state */
+);
+
+#endif
+
+
+